from sentencex.base import Language


class Dutch(Language):
    language = "nl"

    abbreviations = {
        'riv.dir.int."le priv',
        "2d",
        "3e",
        "a.2d",
        "a.a.j.b",
        "a.a",
        "a.f.t",
        "a.g.j.b",
        "a.h.v",
        "a.h.w",
        "a.hosp",
        "a.i",
        "a.j.b",
        "a.j.t",
        "a.m.r",
        "a.m",
        "a.p.m",
        "a.p.r",
        "a.p.t",
        "a.s",
        "a.t.d.f",
        "a.u.b",
        "a.v.a",
        "a.w",
        "aanbev.comm",
        "aanbev",
        "aant",
        "aanv.st",
        "aanw.vnw",
        "aanw",
        "abd",
        "abm",
        "abs",
        "acc.& fisc",
        "acc.act",
        "acc.bedr.m",
        "acc.bedr.t",
        "acc.thema's m.",
        "acc.thema’s m",
        "achterv",
        "act.dr.fam",
        "act.dr",
        "act.fisc",
        "act.soc",
        "adm.akk",
        "adm.besl",
        "adm.lex",
        "adm.onderr",
        "adm.ov",
        "adv.bl",
        "adv",
        "afd",
        "afl",
        "aggl.verord",
        "agr",
        "al",
        "alg.richts",
        "alg",
        "amén",
        "ann.dr.lg",
        "ann.dr.sc.pol",
        "ann.dr",
        "ann.ét.eur",
        "ann.fac.dr.lg",
        "ann.jur.créd.règl.coll",
        "ann.jur.créd",
        "ann.not",
        "ann.parl",
        "ann.prat.comm",
        "app",
        "arb",
        "arbbl",
        "arbh",
        "arbit.besl",
        "arbrb",
        "arr.cass",
        "arr.r.v.st",
        "arr.verbr",
        "arr",
        "arrondrb",
        "art",
        "artw",
        "aud",
        "b.&w",
        "b.a.s",
        "b.a",
        "b.b.o",
        "b.best.dep",
        "b.br.ex",
        "b.coll.fr.gem.comm",
        "b.coll.vl.gem.comm",
        "b.d.cult.r",
        "b.d.gem.ex",
        "b.d.gem.reg",
        "b.dep",
        "b.e.b",
        "b.f.r",
        "b.fr.gem.ex",
        "b.fr.gem.reg",
        "b.i.h",
        "b.inl.j.d",
        "b.inl.s.reg",
        "b.j",
        "b.l",
        "b.lid br.ex",
        "b.lid d.gem.ex",
        "b.lid fr.gem.ex",
        "b.lid vl.ex",
        "b.lid w.gew.ex",
        "b.o.z",
        "b.prov.r",
        "b.r.h",
        "b.s",
        "b.sr",
        "b.stb",
        "b.t.i.r",
        "b.t.s.z",
        "b.t.w.rev",
        "b.v",
        "b.ver.coll.gem.gem.comm",
        "b.verg.r.b",
        "b.versl",
        "b.vl.ex",
        "b.voorl.reg",
        "b.w.gew.ex",
        "b.w",
        "b.z.d.g",
        "b.z.v",
        "b",
        "bab",
        "bank fin.r",
        "bank fin",
        "bedr.org",
        "begins",
        "beheersov",
        "bekendm.comm",
        "bel.besch",
        "bel.w.p",
        "bel",
        "beleidsov",
        "belg",
        "benelux jur",
        "ber.w",
        "ber",
        "besch",
        "besl",
        "beslagr",
        "besluitwet nr",
        "best",
        "bestuurswet",
        "bet",
        "betr",
        "bevest",
        "bew",
        "bijbl.n.bijdr",
        "bijbl",
        "bijl",
        "bijv",
        "bijw",
        "bijz.decr",
        "bin.b",
        "bkh",
        "bl",
        "blz",
        "bm",
        "bn",
        "bnlx merkw",
        "bnlx tek",
        "bnlx uitl",
        "bnw",
        "bouwr",
        "br drs",
        "br.parl",
        "bs",
        "bt drs",
        "btw rev",
        "bull.adm.pénit",
        "bull.ass",
        "bull.b.m.m",
        "bull.bel",
        "bull.best.strafinr",
        "bull.bmm",
        "bull.c.b.n",
        "bull.c.n.c",
        "bull.cbn",
        "bull.centr.arb",
        "bull.cnc",
        "bull.contr",
        "bull.doc.min.fin",
        "bull.f.e.b",
        "bull.feb",
        "bull.fisc.fin.r",
        "bull.i.u.m",
        "bull.inf.ass.secr.soc",
        "bull.inf.i.e.c",
        "bull.inf.i.n.a.m.i",
        "bull.inf.i.r.e",
        "bull.inf.iec",
        "bull.inf.inami",
        "bull.inf.ire",
        "bull.inst.arb",
        "bull.ium",
        "bull.jur.imm",
        "bull.lég.b",
        "bull.off",
        "bull.trim.b.dr.comp",
        "bull.us",
        "bull.v.b.o",
        "bull.vbo",
        "bull",
        "bv i.o",
        "bv",
        "bw int.reg",
        "bw",
        "bxh",
        "byz",
        "c.& f.p",
        "c.& f",
        "c.a.-a",
        "c.a.b.g",
        "c.a",
        "c.c.i",
        "c.c.s",
        "c.c",
        "c.conc.jur",
        "c.d.e",
        "c.d.p.k",
        "c.e",
        "c.ex",
        "c.f",
        "c.h.a",
        "c.i.f.i.c",
        "c.i.f",
        "c.j",
        "c.l",
        "c.n",
        "c.o.d",
        "c.p",
        "c.pr.civ",
        "c.q",
        "c.r.a",
        "c.r",
        "c.s.a",
        "c.s.q.n",
        "c.s",
        "c.v.a",
        "c.v.o",
        "c.v",
        "c",
        "ca",
        "cadeaust",
        "cah.const",
        "cah.dr.europ",
        "cah.dr.immo",
        "cah.dr.jud",
        "cal",
        "cap",
        "carg",
        "cas",
        "cass",
        "cert",
        "cf",
        "ch",
        "chr",
        "chron.d.s",
        "chron.dr.not",
        "chron",
        "cie",
        "cir",
        "circ.z",
        "circ",
        "cit.loc",
        "cit",
        "civ",
        "cl.et.b",
        "cmt",
        "co",
        "cognoss.v",
        "coll",
        "colp.w",
        "com.v.min",
        "com",
        "comm.bijz.ov",
        "comm.erf",
        "comm.fin",
        "comm.ger",
        "comm.handel",
        "comm.pers",
        "comm.pub",
        "comm.straf",
        "comm.v.en v",
        "comm.v",
        "comm.venn",
        "comm.verz",
        "comm.voor",
        "comm",
        "comp",
        "compt.w",
        "computerr",
        "con.m",
        "concl",
        "concr",
        "conf",
        "confl.w.huwbetr",
        "confl.w",
        "cons",
        "conv",
        "coöp",
        "corr.bl",
        "corr",
        "cour de cass",
        "cour.fisc",
        "cour.immo",
        "cridon",
        "crim",
        "crt",
        "cur",
        "curs",
        "d.-g",
        "d.a.v",
        "d.a",
        "d.b.f",
        "d.c.c.r",
        "d.c",
        "d.d.p",
        "d.d",
        "d.e.t",
        "d.gem.r",
        "d.h.z",
        "d.h",
        "d.i.t",
        "d.i",
        "d.j",
        "d.l.r",
        "d.m.v",
        "d.m",
        "d.o.v",
        "d.parl",
        "d.w.z",
        "d",
        "dact",
        "dat",
        "dbesch",
        "dbesl",
        "de advoc",
        "de belg.acc",
        "de burg.st",
        "de dr",
        "de gem",
        "de gerechtsd",
        "de venn",
        "de verz",
        "decr.d",
        "decr.fr",
        "decr.vl",
        "decr.w",
        "decr",
        "deelw",
        "def",
        "dep.opv",
        "dep.rtl",
        "derg",
        "desp",
        "det.mag",
        "deurw.regl",
        "dez",
        "dgl",
        "dhr",
        "disp",
        "diss",
        "div.act",
        "div.bel",
        "div",
        "dl",
        "dln",
        "dnotz",
        "doc.jur.b",
        "doc.min.fin",
        "doc.parl",
        "doc",
        "doctr",
        "dpl.besl",
        "dpl",
        "dr.banc.fin",
        "dr.circ",
        "dr.inform",
        "dr.mr",
        "dr.pén.entr",
        "dr.q.m",
        "dr",
        "drs",
        "dtp",
        "dwz",
        "dyn",
        "e cont",
        "e.a",
        "e.b",
        "e.c.a",
        "e.c",
        "e.d",
        "e.e.a",
        "e.e.g",
        "e.e",
        "e.g.a",
        "e.g",
        "e.h.a",
        "e.i",
        "e.j",
        "e.m.a",
        "e.n.a.c",
        "e.o",
        "e.p.c",
        "e.r.c",
        "e.r.f",
        "e.r.h",
        "e.r.o",
        "e.r.p",
        "e.r.v",
        "e.s.r.a",
        "e.s.t",
        "e.v.a",
        "e.v",
        "e.w",
        "e",
        "e&o.e",
        "ec.pol.r",
        "echos log",
        "econ",
        "ed",
        "ed(s)",
        "eeg verd.v",
        "eex san s",
        "eff",
        "eg rtl",
        "eig.mag",
        "eig",
        "eil",
        "elektr",
        "en antw",
        "en gew",
        "en m",
        "en prov",
        "en s",
        "en w",
        "enmb",
        "entr.et dr",
        "enz",
        "err",
        "et al",
        "et seq",
        "etc",
        "etq",
        "eur.t.s",
        "eur.verd.overdracht strafv",
        "eur",
        "ev rechtsh",
        "ev uitl",
        "ev",
        "evt",
        "ex.crim",
        "ex",
        "exec",
        "f.a.o",
        "f.a.q",
        "f.a.s",
        "f.i.b",
        "f.j.f",
        "f.o.b",
        "f.o.r",
        "f.o.s",
        "f.o.t",
        "f.r",
        "f.supp",
        "f.suppl",
        "f",
        "fa",
        "facs",
        "fare act",
        "fasc",
        "fg",
        "fid.ber",
        "fig",
        "fin.verh.w",
        "fin",
        "fisc.act",
        "fisc.koer",
        "fisc",
        "fl",
        "form",
        "foro",
        "fr.cult.r",
        "fr.gem.r",
        "fr.parl",
        "fr",
        "fra",
        "ft",
        "g.a.v",
        "g.a.w.v",
        "g.a",
        "g.g.d",
        "g.m.t",
        "g.o",
        "g.omt.e",
        "g.p",
        "g.s",
        "g.v",
        "g.w.w",
        "g",
        "geb",
        "gebr",
        "gebrs",
        "gec.decr",
        "gec",
        "ged.st",
        "ged",
        "gedipl",
        "gedr.st",
        "geh",
        "gem.comm",
        "gem.gem.comm",
        "gem.st",
        "gem.stem",
        "gem.w",
        "gem.wet, gem.wet",
        "gem",
        "gemeensch.optr",
        "gemeensch.standp",
        "gemeensch.strat",
        "gemeent.b",
        "gemeent.regl",
        "gemeent.verord",
        "gemeent",
        "gen",
        "geol",
        "geopp",
        "gepubl",
        "ger.deurw",
        "ger.w",
        "gerekw",
        "gereq",
        "gesch",
        "get",
        "getr",
        "gev.m",
        "gev.maatr",
        "gew",
        "ghert",
        "gir.eff.verk",
        "gk",
        "gr",
        "gramm",
        "grat.w",
        "gron,opm.en leermed",
        "grondw",
        "grootb.w",
        "grs",
        "grur ausl",
        "grur int",
        "grvm",
        "grw",
        "gst",
        "gw",
        "h.a.v.o",
        "h.a",
        "h.b.o",
        "h.e.a.o",
        "h.e.g.a",
        "h.e.geb",
        "h.e.gestr",
        "h.l",
        "h.m",
        "h.o",
        "h.r",
        "h.t.l",
        "h.t.m",
        "h.w.geb",
        "hand",
        "handelsn.w",
        "handelspr",
        "handelsr.w",
        "handelsreg.w",
        "handv",
        "harv.l.rev",
        "hc",
        "herald",
        "hert",
        "herz",
        "hfdst",
        "hfst",
        "hgrw",
        "hhr",
        "hist",
        "hooggel",
        "hoogl",
        "hosp",
        "hpw",
        "hr.ms",
        "hr",
        "hregw",
        "hrg",
        "hst",
        "huis.just",
        "huisv.w",
        "huurbl",
        "hv.vn",
        "hw",
        "hyp.w",
        "i.b.s",
        "i.c.m.h",
        "i.c",
        "i.e",
        "i.f.p",
        "i.f",
        "i.g.v",
        "i.h.a",
        "i.h.b",
        "i.h",
        "i.l.pr",
        "i.o",
        "i.p.o",
        "i.p.r",
        "i.p.v",
        "i.pl.v",
        "i.r.d.i",
        "i.s.m",
        "i.t.t",
        "i.v.m",
        "i.v.s",
        "i.v",
        "i.w.tr",
        "i.z",
        "ib",
        "ibid",
        "icip-ing.cons",
        "iem",
        "ind prop",
        "ind",
        "indic.soc",
        "indiv",
        "inf.i.d.a.c",
        "inf.idac",
        "inf.r.i.z.i.v",
        "inf.riziv",
        "inf.soc.secr",
        "inf",
        "ing.cons",
        "ing",
        "inst",
        "int'l & comp.l.q.",
        "int",
        "interm",
        "intern.fisc.act",
        "intern.vervoerr",
        "inv.w",
        "inv.wet",
        "inv",
        "invord.w",
        "inz",
        "ir",
        "irspr",
        "it",
        "iwtr",
        "j.-cl",
        "j.c.b",
        "j.c.e",
        "j.c.fl",
        "j.c.j",
        "j.c.p",
        "j.d.e",
        "j.d.f",
        "j.d.s.c",
        "j.dr.jeun",
        "j.j.d",
        "j.j.p",
        "j.j.pol",
        "j.l.m.b",
        "j.l.o",
        "j.l",
        "j.ordre pharm",
        "j.p.a",
        "j.r.s",
        "j.t.d.e",
        "j.t.dr.eur",
        "j.t.o",
        "j.t.t",
        "j.t",
        "j",
        "jaarl",
        "jb.hand",
        "jb.kred.c.s",
        "jb.kred",
        "jb.l.r.b",
        "jb.lrb",
        "jb.markt",
        "jb.mens",
        "jb.t.r.d",
        "jb.trd",
        "jeugdrb",
        "jeugdwerkg.w",
        "jg",
        "jis",
        "jl",
        "journ.jur",
        "journ.prat.dr.fisc.fin",
        "journ.proc",
        "jrg",
        "jur.comm.fl",
        "jur.dr.soc.b.l.n",
        "jur.f.p.e",
        "jur.fpe",
        "jur.niv",
        "jur.trav.brux",
        "jur",
        "jura falc",
        "jurambt",
        "jv.cass",
        "jv.h.r.j",
        "jv.hrj",
        "jw",
        "k.b",
        "k.g",
        "k.k",
        "k.m.b.o",
        "k.o.o",
        "k.v.k",
        "k.v.v.v",
        "k",
        "kadasterw",
        "kaderb",
        "kador",
        "kbo-nr",
        "kg",
        "kh",
        "kiesw",
        "kind.bes.v",
        "kkr",
        "koopv",
        "kr",
        "krankz.w",
        "ksbel",
        "kt",
        "ktg",
        "ktr",
        "kvdm",
        "kw.r",
        "kymr",
        "kzr",
        "kzw",
        "l.b.o",
        "l.b",
        "l.bas",
        "l.c",
        "l.gew",
        "l.j",
        "l.k",
        "l.l",
        "l.o",
        "l.r.b",
        "l.u.v.i",
        "l.v.r",
        "l.v.w",
        "l.w",
        "l'exp.-compt.b.",
        "l’exp.-compt.b",
        "l",
        "landinr.w",
        "landscrt",
        "larcier cass",
        "lat",
        "law.ed",
        "lett",
        "levensverz",
        "lgrs",
        "lidw",
        "limb.rechtsl",
        "lit",
        "litt",
        "liw",
        "liwet",
        "lk",
        "ll.(l.)l.r",
        "ll",
        "loonw",
        "losbl",
        "ltd",
        "luchtv.w",
        "luchtv",
        "m.a.v.o",
        "m.a.w",
        "m.b.o",
        "m.b.r",
        "m.b.t",
        "m.b",
        "m.d.g.o",
        "m.e.a.o",
        "m.e.r",
        "m.h.d",
        "m.h",
        "m.i.v",
        "m.j.t",
        "m.k",
        "m.m.a",
        "m.m.h.h",
        "m.m.v",
        "m.m",
        "m.n",
        "m.not.fisc",
        "m.nt",
        "m.o",
        "m.r",
        "m.s.a",
        "m.u.p",
        "m.v.a",
        "m.v.h.n",
        "m.v.t",
        "m.z",
        "m",
        "maatr.teboekgest.luchtv",
        "maced",
        "mand",
        "max",
        "mbl.not",
        "me",
        "med.b.u.f.r",
        "med.bufr",
        "med.vbo",
        "med",
        "meerv",
        "meetbr.w",
        "mém.adm",
        "mgr",
        "mgrs",
        "mhd",
        "mi.verantw",
        "mil.bed",
        "mil.ger",
        "mil",
        "min.j.omz",
        "min.just.circ",
        "min",
        "mitt",
        "mnd",
        "mod",
        "mon",
        "monde ass",
        "mouv.comm",
        "mr",
        "ms",
        "muz",
        "mv",
        "mva ii inv",
        "mva inv",
        "n cont",
        "n.a.g",
        "n.a.v",
        "n.a",
        "n.b",
        "n.c",
        "n.chr",
        "n.d.r",
        "n.d",
        "n.e.a",
        "n.g",
        "n.h.b.c",
        "n.j.b",
        "n.j.w",
        "n.j",
        "n.l",
        "n.m.m",
        "n.m",
        "n.n.b",
        "n.n.g",
        "n.n.k",
        "n.n",
        "n.o.m",
        "n.o.t.k",
        "n.rapp",
        "n.tijd.pol",
        "n.v.d.r",
        "n.v.d.v",
        "n.v.h",
        "n.v.o.b",
        "n.v.t",
        "n.v",
        "n",
        "nat.besch.w",
        "nat.omb",
        "nat.pers",
        "ned.cult.r",
        "neg.verkl",
        "nhd",
        "nieuw arch",
        "njcm-bull",
        "nl",
        "nnd",
        "no",
        "not.fisc.m",
        "not.w",
        "not.wet",
        "not",
        "nr",
        "nrs",
        "nste",
        "nt",
        "numism",
        "o.a",
        "o.b",
        "o.c",
        "o.g.v",
        "o.g",
        "o.i.d",
        "o.i",
        "o.m",
        "o.o.d",
        "o.o.v",
        "o.o",
        "o.p",
        "o.r",
        "o.regl",
        "o.s",
        "o.t.s",
        "o.t.t.t",
        "o.t.t.z",
        "o.t.t",
        "o.tk.t",
        "o.v.t.t",
        "o.v.t",
        "o.v.tk.t",
        "o.v.v",
        "o",
        "ob",
        "obsv",
        "octr.gem.regl",
        "octr.regl",
        "octr",
        "oe",
        "oecd mod",
        "off.pol",
        "ofra",
        "ohd",
        "omb",
        "omnia frat",
        "omnil",
        "omz",
        "on.ww",
        "onderr",
        "onfrank",
        "onteig.w",
        "ontw",
        "onuitg",
        "onz",
        "oorl.w",
        "op.cit",
        "opin.pa",
        "opm",
        "or",
        "ord.br",
        "ord.gem",
        "ors",
        "orth",
        "os",
        "osm",
        "ov.w.i",
        "ov.w.ii",
        "ov.ww",
        "ov",
        "overg.w",
        "overw",
        "ovkst",
        "ow kadasterw",
        "oz",
        "p.& b",
        "p.a.o",
        "p.a",
        "p.b.o",
        "p.e",
        "p.g",
        "p.j",
        "p.m.a",
        "p.m",
        "p.o.j.t",
        "p.o",
        "p.p",
        "p.v.s",
        "p.v",
        "p",
        "pachtw",
        "pag",
        "pan",
        "pand.b",
        "pand.pér",
        "parl.gesch",
        "parl.st",
        "parl",
        "part.arb",
        "pas",
        "pasin",
        "pat",
        "pb.c",
        "pb.l",
        "pens",
        "pensioenverz",
        "per.ber.i.b.r",
        "per.ber.ibr",
        "pers",
        "pft",
        "pg wijz.rv",
        "pk",
        "pktg",
        "pli jur",
        "plv",
        "po",
        "pol.off",
        "pol.r",
        "pol.w",
        "pol",
        "politie j",
        "postbankw",
        "postw",
        "pp",
        "pr",
        "preadv",
        "pres",
        "prf",
        "prft",
        "prg",
        "prijz.w",
        "pro jus",
        "proc",
        "procesregl",
        "prof",
        "prot",
        "prov.b",
        "prov.instr.h.m.g",
        "prov.regl",
        "prov.verord",
        "prov.w",
        "prov",
        "publ.cour eur.d.h",
        "publ.eur.court h.r",
        "publ",
        "pun",
        "pw",
        "q.b.d",
        "q.e.d",
        "q.q",
        "q.r",
        "r.a.b.g",
        "r.a.c.e",
        "r.a.j.b",
        "r.b.d.c",
        "r.b.d.i",
        "r.b.s.s",
        "r.c.b",
        "r.c.d.c",
        "r.c.j.b",
        "r.c.s.j",
        "r.c",
        "r.cass",
        "r.d.c",
        "r.d.i.d.c",
        "r.d.i",
        "r.d.j.b",
        "r.d.j.p",
        "r.d.p.c",
        "r.d.s",
        "r.d.t.i",
        "r.e",
        "r.f.s.v.p",
        "r.g.a.r",
        "r.g.c.f",
        "r.g.d.c",
        "r.g.f",
        "r.g.z",
        "r.h.a",
        "r.i.c",
        "r.i.d.a",
        "r.i.e.j",
        "r.i.n",
        "r.i.s.a",
        "r.j.d.a",
        "r.j.i",
        "r.k",
        "r.l.g.b",
        "r.l",
        "r.med.rechtspr",
        "r.med",
        "r.n.b",
        "r.o",
        "r.orde apoth",
        "r.ov",
        "r.p.d.b",
        "r.p.o.t",
        "r.p.r.j",
        "r.p.s",
        "r.p",
        "r.r.d",
        "r.r.s",
        "r.s.v.p",
        "r.s",
        "r.stvb",
        "r.t.d.f",
        "r.t.d.h",
        "r.t.l",
        "r.trim.dr.eur",
        "r.v.a",
        "r.v.k",
        "r.verkb",
        "r.w.d",
        "r.w",
        "r",
        "rap.ann.c.a",
        "rap.ann.c.c",
        "rap.ann.c.e",
        "rap.ann.c.s.j",
        "rap.ann.ca",
        "rap.ann.cass",
        "rap.ann.cc",
        "rap.ann.ce",
        "rap.ann.csj",
        "rapp",
        "rb.kh",
        "rb.van kh",
        "rb",
        "rdn",
        "rdnr",
        "re.pers",
        "rec.c.i.j",
        "rec.c.j.c.e",
        "rec.cij",
        "rec.cjce",
        "rec.cour eur.d.h",
        "rec.gén.enr.not",
        "rec.lois decr.arr",
        "rec",
        "rechtsh",
        "rechtsk.t",
        "rechtspl.zeem",
        "rechtspr.arb.br",
        "rechtspr.b.f.e",
        "rechtspr.bfe",
        "rechtspr.soc.r.b.l.n",
        "recl.reg",
        "rect",
        "red",
        "reg.huiz.bew",
        "reg.w",
        "reg",
        "registr.w",
        "regl.besl",
        "regl.onderr",
        "regl.r.t",
        "regl",
        "rep.eur.court h.r",
        "rép.fisc",
        "rép.not",
        "rep.r.j",
        "rep.rj",
        "rep",
        "req",
        "res",
        "resp",
        "rev.acc.trav",
        "rev.adm",
        "rev.b.compt",
        "rev.b.dr.const",
        "rev.b.dr.intern",
        "rev.b.séc.soc",
        "rev.banc.fin",
        "rev.comm",
        "rev.cons.prud",
        "rev.dr.b",
        "rev.dr.commun",
        "rev.dr.étr",
        "rev.dr.fam",
        "rev.dr.intern.comp",
        "rev.dr.mil",
        "rev.dr.min",
        "rev.dr.pén.mil",
        "rev.dr.pén",
        "rev.dr.rur",
        "rev.dr.u.l.b",
        "rev.dr.ulb",
        "rev.exp",
        "rev.faill",
        "rev.fisc",
        "rev.gd",
        "rev.hist.dr",
        "rev.i.p.c",
        "rev.ipc",
        "rev.not.b",
        "rev.prat.dr.comm",
        "rev.prat.not.b",
        "rev.prat.soc",
        "rev.rec",
        "rev.rw",
        "rev.trav",
        "rev.trim.d.h",
        "rev.trim.dr.fam",
        "rev.urb",
        "rev",
        "rh",
        "richtl",
        "riv.dir.int.priv.proc",
        "riv.dir.int",
        "rk",
        "rln",
        "roln",
        "rom",
        "rondz",
        "rov",
        "rprt",
        "rtl",
        "rubr",
        "ruilv.wet",
        "rv.verdr",
        "rvkb",
        "s.a",
        "s.b.n",
        "s.ct",
        "s.d",
        "s.e.c",
        "s.e.et.o",
        "s.e.w",
        "s.exec.rept",
        "s.hrg",
        "s.j.b",
        "s.l.e.a",
        "s.l.n.d",
        "s.l",
        "s.p.a",
        "s.s",
        "s.t.b",
        "s.t",
        "s.v.p",
        "s.v",
        "s",
        "samenw",
        "sc",
        "sch",
        "scheidsr.uitspr",
        "schepel.besl",
        "secr.comm",
        "secr.gen",
        "sect.soc",
        "sess",
        "sir",
        "soc.act",
        "soc.best",
        "soc.kron",
        "soc.r",
        "soc.sw",
        "soc.weg",
        "soc",
        "sofi-nr",
        "somm.ann",
        "somm",
        "sp.c.c",
        "sr",
        "ss",
        "st.doc.b.c.n.a.r",
        "st.doc.bcnar",
        "st.vw",
        "st",
        "stagever",
        "stas",
        "stat",
        "stb",
        "stbl",
        "stcrt",
        "stichting i.v",
        "strafz",
        "stud.dipl",
        "su",
        "subs",
        "subst",
        "succ.w",
        "suppl",
        "sv",
        "sw",
        "t.a.a",
        "t.a.n",
        "t.a.p",
        "t.a.s.n",
        "t.a.v.w",
        "t.a.v",
        "t.a",
        "t.aann",
        "t.acc",
        "t.agr.r",
        "t.app",
        "t.b.b.r",
        "t.b.h",
        "t.b.m",
        "t.b.o",
        "t.b.p",
        "t.b.r",
        "t.b.s",
        "t.b.v",
        "t.bankw",
        "t.belg.not",
        "t.desk",
        "t.e.m",
        "t.e.p",
        "t.f.r",
        "t.fam",
        "t.fin.r",
        "t.g.r",
        "t.g.t",
        "t.g.v",
        "t.gem",
        "t.gez",
        "t.huur",
        "t.i.n",
        "t.in b.z",
        "t.j.k",
        "t.l.l",
        "t.l.v",
        "t.m.r",
        "t.m.w",
        "t.m",
        "t.mil.r",
        "t.mil.strafr",
        "t.not",
        "t.o.r.b",
        "t.o.v",
        "t.o",
        "t.ontv",
        "t.orde geneesh",
        "t.p.r",
        "t.pol",
        "t.r.d.& i",
        "t.r.g",
        "t.r.o.s",
        "t.r.v",
        "t.r",
        "t.s.r",
        "t.strafr",
        "t.t",
        "t.u",
        "t.v.c",
        "t.v.g",
        "t.v.m.r",
        "t.v.o",
        "t.v.v.d.b",
        "t.v.v",
        "t.v.w",
        "t.verz",
        "t.vred",
        "t.vreemd",
        "t.w.k",
        "t.w.v.r",
        "t.w.v",
        "t.w",
        "t.wrr",
        "t.z.t",
        "t.z.v",
        "t.z",
        "t",
        "taalk",
        "tar.burg.z",
        "td",
        "techn",
        "tek.mod",
        "telecomm",
        "tijdschr",
        "toel.st.v.w",
        "toel",
        "toep.regl",
        "toep",
        "tom",
        "top",
        "trans.b",
        "transp.r",
        "trav.com.ét.et lég.not",
        "trb",
        "trib.civ",
        "trib.gr.inst",
        "trib",
        "trim",
        "ts",
        "turnh.rechtsl",
        "tvpol",
        "tvpr",
        "tvrechtsgesch",
        "tw",
        "u.a.r",
        "u.a.v",
        "u.a",
        "u.c.c",
        "u.c",
        "u.g",
        "u.p",
        "u.s.d.c",
        "u.s",
        "u",
        "uitdr",
        "uitl.w",
        "uitv.besch.div.b",
        "uitv.besl.bel.rv",
        "uitv.besl.l.b",
        "uitv.besl",
        "uitv.reg.afd.verm",
        "uitv.reg.bel.d",
        "uitv.reg.lb",
        "uitv.reg.succ.w",
        "uitv.reg",
        "univ.verkl",
        "univ",
        "v.& f",
        "v.a.v",
        "v.a",
        "v.b.o",
        "v.bp prot",
        "v.c",
        "v.chr",
        "v.h",
        "v.huw.verm",
        "v.i.o",
        "v.i",
        "v.k.a",
        "v.m",
        "v.o.f",
        "v.o.n",
        "v.onderh.verpl",
        "v.p",
        "v.r",
        "v.s.o",
        "v.t.t.t",
        "v.t.t",
        "v.tk.t",
        "v.toep.r.vert",
        "v.v.b",
        "v.v.g",
        "v.v.t.t",
        "v.v.t",
        "v.v.tk.t",
        "v.w.b",
        "v.z.m",
        "v",
        "vb.bo",
        "vb",
        "vbb",
        "vc",
        "vd",
        "veldw",
        "ver.k",
        "ver.verg.gem",
        "ver",
        "verbr",
        "verd",
        "verdr.v",
        "verdr",
        "verdrag benel.i.z",
        "verenw",
        "verg.fr.gem",
        "verg",
        "verkl.herz.gw",
        "verkl",
        "verl",
        "vern",
        "verord",
        "vers.r",
        "versch",
        "versl.c.s.w",
        "versl.csw",
        "vert",
        "verv",
        "verw",
        "verz.schr",
        "verz.w",
        "verz.wett.besl",
        "verz.wett.decr.besl",
        "verz",
        "vgl",
        "vid",
        "vigiles jb",
        "viss.w",
        "vl.parl",
        "vl.r",
        "vl.t.gez",
        "vl.w.reg",
        "vl.w.succ",
        "vlg",
        "vn",
        "vnl",
        "vnw",
        "vo.bl",
        "vo",
        "voegw",
        "vol",
        "volg",
        "volt",
        "voorl",
        "voorz",
        "vord.w",
        "vorst.d",
        "vr",
        "vred",
        "vrg",
        "vrijgrs",
        "vs",
        "vt",
        "vvsr jb",
        "vw",
        "vz",
        "vzngr",
        "vzr",
        "w.a",
        "w.b.r",
        "w.c.h",
        "w.conf.huw",
        "w.conf.huwelijksb",
        "w.consum.kr",
        "w.f.r",
        "w.g",
        "w.gelijke beh",
        "w.gew.r",
        "w.ident.pl",
        "w.just.doc",
        "w.kh",
        "w.l.r",
        "w.l.v",
        "w.mil.straf.spr",
        "w.n",
        "w.not.ambt",
        "w.o.d.huurcomm",
        "w.o.d.k",
        "w.o",
        "w.openb.manif",
        "w.parl",
        "w.r",
        "w.reg",
        "w.succ",
        "w.u.b",
        "w.uitv.pl.verord",
        "w.v.k",
        "w.v.m.s",
        "w.v.r",
        "w.v.w",
        "w.v",
        "w.venn",
        "w",
        "wac",
        "wd",
        "wet a.b",
        "wet bel.rv",
        "wet c.a.o",
        "wet c.o",
        "wet div.bel",
        "wet ksbel",
        "wet l.v",
        "wetb",
        "wgb",
        "winkelt.w",
        "wisk",
        "wka-verkl",
        "wnd",
        "won.w",
        "woningw",
        "woonr.w",
        "wrr.ber",
        "wrr",
        "wrsch",
        "ws",
        "wsch",
        "wsr",
        "wtvb",
        "ww",
        "x.d",
        "z cont",
        "z.a",
        "z.g",
        "z.i",
        "z.j",
        "z.o.z",
        "z.p",
        "z.s.m",
        "zesde richtl",
        "zg",
        "zgn",
        "zn",
        "znw",
        "zr.ms",
        "zr",
    }



from sentencex.base import Language

from .en import English


class Gujarati(Language):
    language = "gu"

    # Writing English abbreviation like Dr as such inside Tamil is common
    abbreviations = English.abbreviations.union(
        {
            "એ",
            "બી",
            "સી",
            "ડી",
            "ઈ",
            "એફ",
            "જી",
            "એચ",
            "આઈ",
            "જે",
            "કે",
            "એલ",
            "એમ",
            "એન",
            "ઓ",
            "પી",
            "ક્યૂ",
            "આર",
            "એસ",
            "ટી",
            "યૂ",
            "વી",
            "ડબલ્યૂ",
            "એક્સ",
            "વાય",
            "જેડ",
        }
    )
